pub enum PolicyBlockError {
PreconditionMismatch {
message: String,
},
SafetyGateDenial {
message: String,
},
PolicyDenial {
message: String,
},
CapsExceeded {
message: String,
},
}Expand description
Policy block errors that should result in exit code 2.
Variants
PreconditionMismatch
One or more preconditions failed (file changed, missing, sha256 mismatch).
SafetyGateDenial
A fix was denied by the safety gate (guarded/unsafe not allowed).
PolicyDenial
A fix was denied by the allow/deny policy.
CapsExceeded
Caps exceeded (max operations, max files, max diff size).